# -*- coding: utf-8 -*-
import pkg_resources

__title__ = "trailblazer"
__version__ = pkg_resources.get_distribution(__title__).version
